==> alfresco-repository-23.3.21.1-sources.jar: org/alfresco/repo/solr/SOLRWatcherJob.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.solr;

import org.alfresco.repo.solr.SOLRAdminClient.SolrTracker;
import org.quartz.Job;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

/**
 * A Quartz job that pings Solr to determine if it is alive
 * 
 * @since 4.0
 *
 */
public class SOLRWatcherJob implements Job
{
	public SOLRWatcherJob()
    {
        super();
    }
	
    /*
     * (non-Javadoc)
     * @see org.quartz.Job#execute(org.quartz.JobExecutionContext)
     */
    @Override
    public void execute(JobExecutionContext jec) throws JobExecutionException
    {
        SolrTracker solrTracker = (SolrTracker)jec.getJobDetail().getJobDataMap().get("SOLR_TRACKER");
    	solrTracker.pingSolr();
    }
}

==> alfresco-repository-25.3.0.68-sources.jar: org/alfresco/repo/solr/SOLRWatcherJob.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.solr;

import org.quartz.Job;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

import org.alfresco.repo.solr.SOLRAdminClient.SolrTracker;

/**
 * A Quartz job that pings Solr to determine if it is alive
 * 
 * @since 4.0
 *
 */
public class SOLRWatcherJob implements Job
{
    public SOLRWatcherJob()
    {
        super();
    }

    /* (non-Javadoc)
     * 
     * @see org.quartz.Job#execute(org.quartz.JobExecutionContext) */
    @Override
    public void execute(JobExecutionContext jec) throws JobExecutionException
    {
        SolrTracker solrTracker = (SolrTracker) jec.getJobDetail().getJobDataMap().get("SOLR_TRACKER");
        solrTracker.pingSolr();
    }
}
